@@ -42,8 +42,17 @@ class ClSetupVideoAction(Action):
     failedMessage = __("Failed to configure the video settings!")
     interruptMessage = __("Configuration manually interrupted")
 
-    addon_tasks = [
+    prev_tasks = [
         # проверить и настроить параметры для nvidia драйвера
+        {'name': 'drop_xorg_log',
+         'method': 'Install.drop_xorg_logs()',
+         'condition': lambda Get: (
+            Get('os_install_x11_video_drv_prev')
+            != Get('os_install_x11_video_drv'))
+        },
+    ]
+
+    addon_tasks = [
         {'name': 'check_video',
          'message': __("Checking the video driver"),
          'method': 'Install.checkVideoDriver()',
@@ -81,7 +90,7 @@ class ClSetupVideoAction(Action):
 
     def __init__(self):
         # список задач для действия
-        self.tasks = [
+        self.tasks = self.prev_tasks + [
             {'name': 'apply_templates',
              'message': self.templateTaskMessage,
              # наложить шаблоны на текущий дистрибутив, включая clt шаблоны
@@ -98,6 +107,7 @@ class ClSetupSystemAction(ClSetupVideoAction):
     """
     Объект настройки всех параметров системы
     """
+    prev_tasks = []
     templateTaskMessage = __("The system is being configured")
     successMessage = __("System configured!")
     failedMessage = __("Failed to configure the system!")
@@ -108,16 +118,33 @@ class ClSetupAudioAction(ClSetupSystemAction):
     Действие для настройки аудио параметров
     """
     addon_tasks = []
+    prev_tasks = []
     templateTaskMessage = __("The audio settings are being configured")
     successMessage = __("Audio settings configured!")
     failedMessage = __("Failed to configure the audio parameters!")
 
 
+class ClSetupThemesAction(ClSetupSystemAction):
+    """
+    Действие для настройки тем
+    """
+    addon_tasks = []
+    prev_tasks = [
+        {'name': 'init_themes',
+         'method': 'Install.init_themes()'
+         },
+    ]
+    templateTaskMessage = __("The themes are being configured")
+    successMessage = __("Themes configured!")
+    failedMessage = __("Failed to configure themes!")
+
+
 class ClSetupLocaleAction(ClSetupSystemAction):
     """
     Действие для настройки языковых параметров
     """
     addon_tasks = []
+    prev_tasks = []
     templateTaskMessage = \
         __("The localization and time options are being configured")
     successMessage = __("System configured!")
@@ -152,6 +179,7 @@ class ClSetupBootAction(ClSetupSystemAction):
     successMessage = __("Boot parameters configured!")
     failedMessage = __("Failed to configure the boot parameters!")
 
+    prev_tasks = []
     addon_tasks = [
         # установить загрузчик
         {'name': 'prepare_bootloader',
