@@ -156,8 +156,11 @@ class VariableClMigrateRootShadowPwd(ReadonlyVariable):
             rootPasswd = ""
         # if root password is "root"
         enc = get_shadow_hash()
-        if rootPasswd and enc.identify(rootPasswd):
-            if enc.verify("root", rootPasswd):
+        if rootPasswd:
+            if enc.identify(rootPasswd):
+                if enc.verify("root", rootPasswd):
+                    rootPasswd = ""
+            else:
                 rootPasswd = ""
         return rootPasswd or ""
 
@@ -185,8 +188,8 @@ class VariableClGrubPasswdSet(GrubHelper, Variable):
     opt = ["--grub-passwd"]
 
     def init(self):
-        self.help = _("Use password for grub")
-        self.label = _("use password for grub")
+        self.help = _("use root password for editing grub menu")
+        self.label = _("Use root password for editing grub menu")
 
     def get(self):
         if path.exists(self.grub_passwd_file):
@@ -203,7 +206,7 @@ class VariableClGrubPwd(GrubHelper, Variable):
     type = "password"
 
     def init(self):
-        self.help = _("grub password")
+        self.help = _("set grub password")
         self.label = _("Grub password")
 
     def get(self):
@@ -250,8 +253,8 @@ class VariableClGrubRemovePwdSet(Variable):
     opt = ["--remove-passwd"]
 
     def init(self):
-        self.help = _("remove grub password")
-        self.label = _("Remove grub password")
+        self.help = _("remove the password for editing the grub menu")
+        self.label = _("Remove the grub menu password")
 
 
 class VariableClInstallHomeCryptSet(UserHelper, Variable):
